=======================
The ``getlino`` package
=======================




A tool to install and configure Lino in different environments.

The central project homepage is http://getlino.lino-framework.org

    
